-- 
-- @author	TwistedGA
-- @date	30/09/2022
-- @ver		1.1.0.0
--
-- Portions of this script was authored by Giants and modified by the above. 
-- Very few changes were made to the original functions and conditions
-- have been set based on the desired output. Modify at your own risk.
--

relightStandalone = {}
relightStandalone.modDir = g_currentModDirectory
relightStandalone.xmlFilename = Utils.getFilename('data/relightStandalone.xml', relightStandalone.modDir)

function relightStandalone:loadEnvironment(xmlFile)
	--local filename = Utils.getFilename(getXMLString(xmlFile, 'map.environment#filename'), self.baseDirectory) --Disable default environment fetch.
	self.environment = Environment.new(self)
	--self.environment:load(filename) --Disable default environment loading.
	self.environment:load(relightStandalone.xmlFilename)
	if self.missionInfo.environmentXMLLoad ~= nil and self:getIsServer() then
		local envXmlFile = loadXMLFile('environmentXML', self.missionInfo.environmentXMLLoad)
		self.environment:loadFromXMLFile(envXmlFile, 'environment')
		delete(envXmlFile)
	end
	self.hud:setEnvironment(self.environment)
	self.inGameMenu:setEnvironment(self.environment)
end
Mission00.loadEnvironment = Utils.overwrittenFunction(Mission00.loadEnvironment, relightStandalone.loadEnvironment)

--Override default !mapDir! to load envMap and colorGradings from !modDir! instead.
function relightStandalone:load(xmlFile, baseKey)
	self.heightAngleLimitRotation = math.rad(xmlFile:getFloat(baseKey .. ".sunRotation#heightAngleLimitRotation", 60))
	self.heightAngleLimitRotationStart = math.rad(xmlFile:getFloat(baseKey .. ".sunRotation#heightAngleLimitRotationStart", 56))
	self.heightAngleLimitRotationEnd = math.rad(xmlFile:getFloat(baseKey .. ".sunRotation#heightAngleLimitRotationEnd", 80))
	self.sunRotationCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".sunRotation", true)
	self.moonBrightnessScaleCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".moonBrightnessScale")
	self.moonSizeScaleCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".moonSizeScale")
	self.sunIsPrimaryCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".sunIsPrimary")
	self.sunBrightnessScaleCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".sunBrightnessScale")
	self.sunSizeScaleCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".sunSizeScale")
	self.asymmetryFactorCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".asymmetryFactor")
	self.primaryExtraterrestrialColorCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".primaryExtraterrestrialColor")
	self.secondaryExtraterrestrialColorCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".secondaryExtraterrestrialColor")
	self.primaryDynamicLightingScaleCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".primaryDynamicLightingScale")
	self.lightScatteringRotationCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".lightScatteringRotation", true)
	self.autoExposureCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".autoExposure")

	if Platform.usesFixedExposure then
		self.fixedExposureCurveData = self:loadCurveDataFromXML(xmlFile, baseKey .. ".fixedExposure")
	end

	local day = xmlFile:getString(baseKey .. ".colorGrading.day#filename")

	if day ~= nil then
		self.colorGradingDay = Utils.getFilename(day, relightStandalone.modDir) -- Edited to !modDir!
	end

	local night = xmlFile:getString(baseKey .. ".colorGrading.night#filename")
	
	if night ~= nil then
		self.colorGradingNight = Utils.getFilename(night, relightStandalone.modDir) -- Edited to !modDir!
	else
		self.colorGradingNight = self.colorGradingDay
	end

	self.bloomMagnitude = xmlFile:getFloat(baseKey .. ".bloom#magnitude") or 0.5
	self.bloomThreshold = xmlFile:getFloat(baseKey .. ".bloom#threshold") or 2

	setBloomMagnitude(self.bloomMagnitude)
	setBloomMaskThreshold(self.bloomThreshold)

	if g_currentMission.xmlFile ~= nil then
		self.envMapBasePath = xmlFile:getString(baseKey .. ".envMap#basePath")

		if self.envMapBasePath ~= nil then
			self.envMapBasePath = Utils.getFilename(self.envMapBasePath, relightStandalone.modDir) -- Edited to !modDir!
		end

		self.envMapTimes = {}

		xmlFile:iterate(baseKey .. ".envMap.timeProbe", function (_, timeProbeKey)
			local timeHours = xmlFile:getFloat(timeProbeKey .. "#timeHours")

			if timeHours ~= nil then
				table.insert(self.envMapTimes, timeHours)
			end
		end)
		table.sort(self.envMapTimes)

		self.envMapRenderingMode = false
	end

	self.albedoGroundColors = {
		[Environment.SEASON.SPRING] = xmlFile:getVector(baseKey .. ".envAlbedoGroundColors.spring#value", {
			0,
			0,
			0
		}, 3),
		[Environment.SEASON.SUMMER] = xmlFile:getVector(baseKey .. ".envAlbedoGroundColors.summer#value", {
			0,
			0,
			0
		}, 3),
		[Environment.SEASON.AUTUMN] = xmlFile:getVector(baseKey .. ".envAlbedoGroundColors.autumn#value", {
			0,
			0,
			0
		}, 3),
		[Environment.SEASON.WINTER] = xmlFile:getVector(baseKey .. ".envAlbedoGroundColors.winter#value", {
			0,
			0,
			0
		}, 3),
		snow = xmlFile:getVector(baseKey .. ".envAlbedoGroundColors.snow#value", {
			0,
			0,
			0
		}, 3)
	}
	self.lastUpdateDayTime = 0

	return true
end
Lighting.load = relightStandalone.load